summaryrefslogtreecommitdiffstats
path: root/smb4k/smb4k.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/smb4k.h')
-rw-r--r--smb4k/smb4k.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/smb4k/smb4k.h b/smb4k/smb4k.h
index 79cc597..9385f15 100644
--- a/smb4k/smb4k.h
+++ b/smb4k/smb4k.h
@@ -65,12 +65,12 @@ class Smb4KApp : public KParts::DockMainWindow
protected:
/**
- * Reimplemented from KMainWindow.
+ * Reimplemented from TDEMainWindow.
*/
bool queryExit();
/**
- * Reimplemented from KMainWindow.
+ * Reimplemented from TDEMainWindow.
*/
bool queryClose();
@@ -139,7 +139,7 @@ class Smb4KApp : public KParts::DockMainWindow
*
* @param action The action that has been highlighted
*/
- void slotActionHighlighted( KAction *action );
+ void slotActionHighlighted( TDEAction *action );
/**
* This slot sets the keyboard focus to the network browser and shows it
@@ -211,9 +211,9 @@ class Smb4KApp : public KParts::DockMainWindow
enum StatusBarItem{ Message = 0, Progress = 1, Version = 2 };
/**
* The currently highlighted KAction.
*/
- KAction *m_action;
+ TDEAction *m_action;
/**
* This holds the config entry of the current shares
@@ -211,9 +211,9 @@ class Smb4KApp : public KParts::DockMainWindow
enum StatusBarItem{ Message = 0, Progress = 1, Version = 2 };
/**
- * The currently highlighted KAction.
+ * The currently highlighted TDEAction.
*/